#! /bin/bash
#
# Author: Natalia Bidart <natalia.bidart@canonical.com>
#
# Copyright 2010-2012 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# In addition, as a special exception, the copyright holders give
# permission to link the code of portions of this program with the
# OpenSSL library under certain conditions as described in each
# individual source file, and distribute linked combinations
# including the two.
# You must obey the GNU General Public License in all respects
# for all of the code used other than OpenSSL.  If you modify
# file(s) with this exception, you may extend this exception to your
# version of the file(s), but you are not obligated to do so.  If you
# do not wish to do so, delete this exception statement from your
# version.  If you delete this exception statement from all source
# files in the program, then also delete it here.
QT_TESTS_PATH="ubuntu_sso/qt/tests, ubuntu_sso/qt/main/tests"
GTK_TESTS_PATH=ubuntu_sso/gtk/tests
WINDOWS_TESTS=test_windows.py

set -e

if [ $# -ne 0 ]; then
    # run specific module given by the caller
    MODULE="$@"
else
    # run all tests, useful for tarmac and reviews
    MODULE="ubuntu_sso"
fi

style_check() {
    u1lint --ignore ubuntu_sso/qt/ui
    if [ -x `which pep8` ]; then
        pep8 --exclude '.svn,CVS,.bzr,.hg,.git,*_ui.py,*_rc.py' --repeat . bin/*
    else
        echo "Please install the 'pep8' package."
    fi
}
unset GTK_MODULES

XVFB_CMDLINE=""
XVFB=$(which xvfb-run)
if [ $XVFB ]; then
    XVFB_CMDLINE="$XVFB -a"
fi

echo "*** Running GTK test suite for ""$MODULE"" ***"
$XVFB_CMDLINE u1trial --reactor=gi --gui -p "$QT_TESTS_PATH" -i "test_windows.py,test_qt.py" "$MODULE"
rm -rf _trial_temp

# hack to avoid:
# g_dbus_connection_real_closed: Remote peer vanished with error: Underlying
# GIOStream returned 0 bytes on an async read (g-io-error-quark, 0). Exiting.
sleep 3

echo "*** Running QT test suite for ""$MODULE"" ***"
./setup.py build
$XVFB_CMDLINE u1trial --reactor=qt4 --gui -p "$GTK_TESTS_PATH" -i "test_windows.py" "$MODULE"
rm -rf _trial_temp
rm -rf build

style_check
